projectal.enums API documentation

# projectal.enums

Enums use readable names for string values expected by the Projectal API.

    # Example usage
    from projectal.enums import ConstraintType

    task = projectal.Task.create(project, {
        'name': 'Example Task',
        'constraintType': ConstraintType.ASAP,
        'taskType': TaskType.Task
    })

View Source

      1"""
      2Enums use readable names for string values expected by the Projectal
      3API.
      4
      5```
      6# Example usage
      7from projectal.enums import ConstraintType
      8
      9task = projectal.Task.create(project, {
     10    'name': 'Example Task',
     11    'constraintType': ConstraintType.ASAP,
     12    'taskType': TaskType.Task
     13})
     14```
     15"""
     16
     17
     18class Currency:
     19    AED = "AED"
     20    ARS = "ARS"
     21    AUD = "AUD"
     22    BGN = "BGN"
     23    BRL = "BRL"
     24    CAD = "CAD"
     25    CHF = "CHF"
     26    CLP = "CLP"
     27    CNY = "CNY"
     28    COP = "COP"
     29    CZK = "CZK"
     30    DKK = "DKK"
     31    EUR = "EUR"
     32    GBP = "GBP"
     33    HKD = "HKD"
     34    HUF = "HUF"
     35    IDR = "IDR"
     36    ILS = "ILS"
     37    INR = "INR"
     38    JPY = "JPY"
     39    KRW = "KRW"
     40    MXN = "MXN"
     41    MYR = "MYR"
     42    NOK = "NOK"
     43    NZD = "NZD"
     44    PEN = "PEN"
     45    PHP = "PHP"
     46    PKR = "PKR"
     47    PLN = "PLN"
     48    RON = "RON"
     49    RUB = "RUB"
     50    SAR = "SAR"
     51    SEK = "SEK"
     52    SGD = "SGD"
     53    THB = "THB"
     54    TRY = "TRY"
     55    TWD = "TWD"
     56    UAH = "UAH"
     57    USD = "USD"
     58    ZAR = "ZAR"
     59
     60
     61class TaskType:
     62    Project = "Project"
     63    Task = "Task"
     64    Milestone = "Milestone"
     65
     66
     67class ConstraintType:
     68    ASAP = "As_soon_as_possible"
     69    ALAP = "As_late_as_possible"
     70    SNET = "Start_no_earlier_than"
     71    SNLT = "Start_no_later_than"
     72    FNET = "Finish_no_earlier_than"
     73    FNLT = "Finish_no_later_than"
     74    MSO = "Must_start_on"
     75    MFO = "Must_finish_on"
     76
     77
     78class StaffType:
     79    Casual = "Casual"
     80    Contractor = "Contractor"
     81    Consultant = "Consultant"
     82    Freelance = "Freelance"
     83    Intern = "Intern"
     84    FullTime = "Full_Time"
     85    PartTime = "Part_Time"
     86
     87
     88class PayFrequency:
     89    # OneShot = "One_shot"
     90    Annually = "Annually"
     91    Monthly = "Monthly"
     92    Hourly = "Hourly"
     93    Daily = "Daily"
     94    Weekly = "Weekly"
     95
     96
     97class DateLimit:
     98    Min = "1970-01-01"
     99    Max = "3000-01-01"
    100
    101
    102class CompanyType:
    103    Primary = "Primary"
    104    Subsidiary = "Subsidiary"
    105    Contractor = "Contractor"
    106    Partner = "Partner"
    107    Affiliate = "Affiliate"
    108    Office = "Office"
    109    Division = "Division"
    110
    111
    112class CalendarType:
    113    Leave = "Leave"
    114    Sunday = "Sunday"
    115    Monday = "Monday"
    116    Tuesday = "Tuesday"
    117    Wednesday = "Wednesday"
    118    Thursday = "Thursday"
    119    Friday = "Friday"
    120    Saturday = "Saturday"
    121    Working = "Working"
    122
    123
    124class SkillLevel:
    125    Junior = "Junior"
    126    Mid = "Mid"
    127    Senior = "Senior"
    128
    129
    130class GanttLinkType:
    131    FinishToStart = "Finish_to_start"
    132    StartToStart = "Start_to_start"
    133    FinishToFinish = "Finish_to_finish"
    134    StartToFinish = "Start_to_finish"
    135
    136
    137class ComplexityLevel:
    138    Low = "Low"
    139    Medium = "Medium"
    140    High = "High"
    141
    142
    143class PriorityLevel:
    144    Low = "Low"
    145    Normal = "Normal"
    146    High = "High"

class Currency: View Source

    19class Currency:
    20    AED = "AED"
    21    ARS = "ARS"
    22    AUD = "AUD"
    23    BGN = "BGN"
    24    BRL = "BRL"
    25    CAD = "CAD"
    26    CHF = "CHF"
    27    CLP = "CLP"
    28    CNY = "CNY"
    29    COP = "COP"
    30    CZK = "CZK"
    31    DKK = "DKK"
    32    EUR = "EUR"
    33    GBP = "GBP"
    34    HKD = "HKD"
    35    HUF = "HUF"
    36    IDR = "IDR"
    37    ILS = "ILS"
    38    INR = "INR"
    39    JPY = "JPY"
    40    KRW = "KRW"
    41    MXN = "MXN"
    42    MYR = "MYR"
    43    NOK = "NOK"
    44    NZD = "NZD"
    45    PEN = "PEN"
    46    PHP = "PHP"
    47    PKR = "PKR"
    48    PLN = "PLN"
    49    RON = "RON"
    50    RUB = "RUB"
    51    SAR = "SAR"
    52    SEK = "SEK"
    53    SGD = "SGD"
    54    THB = "THB"
    55    TRY = "TRY"
    56    TWD = "TWD"
    57    UAH = "UAH"
    58    USD = "USD"
    59    ZAR = "ZAR"

AED = 'AED'
ARS = 'ARS'
AUD = 'AUD'
BGN = 'BGN'
BRL = 'BRL'
CAD = 'CAD'
CHF = 'CHF'
CLP = 'CLP'
CNY = 'CNY'
COP = 'COP'
CZK = 'CZK'
DKK = 'DKK'
EUR = 'EUR'
GBP = 'GBP'
HKD = 'HKD'
HUF = 'HUF'
IDR = 'IDR'
ILS = 'ILS'
INR = 'INR'
JPY = 'JPY'
KRW = 'KRW'
MXN = 'MXN'
MYR = 'MYR'
NOK = 'NOK'
NZD = 'NZD'
PEN = 'PEN'
PHP = 'PHP'
PKR = 'PKR'
PLN = 'PLN'
RON = 'RON'
RUB = 'RUB'
SAR = 'SAR'
SEK = 'SEK'
SGD = 'SGD'
THB = 'THB'
TRY = 'TRY'
TWD = 'TWD'
UAH = 'UAH'
USD = 'USD'
ZAR = 'ZAR'
class TaskType: View Source

    62class TaskType:
    63    Project = "Project"
    64    Task = "Task"
    65    Milestone = "Milestone"

Project = 'Project'
Task = 'Task'
Milestone = 'Milestone'
class ConstraintType: View Source

    68class ConstraintType:
    69    ASAP = "As_soon_as_possible"
    70    ALAP = "As_late_as_possible"
    71    SNET = "Start_no_earlier_than"
    72    SNLT = "Start_no_later_than"
    73    FNET = "Finish_no_earlier_than"
    74    FNLT = "Finish_no_later_than"
    75    MSO = "Must_start_on"
    76    MFO = "Must_finish_on"

ASAP = 'As_soon_as_possible'
ALAP = 'As_late_as_possible'
SNET = 'Start_no_earlier_than'
SNLT = 'Start_no_later_than'
FNET = 'Finish_no_earlier_than'
FNLT = 'Finish_no_later_than'
MSO = 'Must_start_on'
MFO = 'Must_finish_on'
class StaffType: View Source

    79class StaffType:
    80    Casual = "Casual"
    81    Contractor = "Contractor"
    82    Consultant = "Consultant"
    83    Freelance = "Freelance"
    84    Intern = "Intern"
    85    FullTime = "Full_Time"
    86    PartTime = "Part_Time"

Casual = 'Casual'
Contractor = 'Contractor'
Consultant = 'Consultant'
Freelance = 'Freelance'
Intern = 'Intern'
FullTime = 'Full_Time'
PartTime = 'Part_Time'
class PayFrequency: View Source

    89class PayFrequency:
    90    # OneShot = "One_shot"
    91    Annually = "Annually"
    92    Monthly = "Monthly"
    93    Hourly = "Hourly"
    94    Daily = "Daily"
    95    Weekly = "Weekly"

Annually = 'Annually'
Monthly = 'Monthly'
Hourly = 'Hourly'
Daily = 'Daily'
Weekly = 'Weekly'
class DateLimit: View Source

     98class DateLimit:
     99    Min = "1970-01-01"
    100    Max = "3000-01-01"

Min = '1970-01-01'
Max = '3000-01-01'
class CompanyType: View Source

    103class CompanyType:
    104    Primary = "Primary"
    105    Subsidiary = "Subsidiary"
    106    Contractor = "Contractor"
    107    Partner = "Partner"
    108    Affiliate = "Affiliate"
    109    Office = "Office"
    110    Division = "Division"

Primary = 'Primary'
Subsidiary = 'Subsidiary'
Contractor = 'Contractor'
Partner = 'Partner'
Affiliate = 'Affiliate'
Office = 'Office'
Division = 'Division'
class CalendarType: View Source

    113class CalendarType:
    114    Leave = "Leave"
    115    Sunday = "Sunday"
    116    Monday = "Monday"
    117    Tuesday = "Tuesday"
    118    Wednesday = "Wednesday"
    119    Thursday = "Thursday"
    120    Friday = "Friday"
    121    Saturday = "Saturday"
    122    Working = "Working"

Leave = 'Leave'
Sunday = 'Sunday'
Monday = 'Monday'
Tuesday = 'Tuesday'
Wednesday = 'Wednesday'
Thursday = 'Thursday'
Friday = 'Friday'
Saturday = 'Saturday'
Working = 'Working'
class SkillLevel: View Source

    125class SkillLevel:
    126    Junior = "Junior"
    127    Mid = "Mid"
    128    Senior = "Senior"

Junior = 'Junior'
Mid = 'Mid'
Senior = 'Senior'
class GanttLinkType: View Source

    131class GanttLinkType:
    132    FinishToStart = "Finish_to_start"
    133    StartToStart = "Start_to_start"
    134    FinishToFinish = "Finish_to_finish"
    135    StartToFinish = "Start_to_finish"

FinishToStart = 'Finish_to_start'
StartToStart = 'Start_to_start'
FinishToFinish = 'Finish_to_finish'
StartToFinish = 'Start_to_finish'
class ComplexityLevel: View Source

    138class ComplexityLevel:
    139    Low = "Low"
    140    Medium = "Medium"
    141    High = "High"

Low = 'Low'
Medium = 'Medium'
High = 'High'
class PriorityLevel: View Source

    144class PriorityLevel:
    145    Low = "Low"
    146    Normal = "Normal"
    147    High = "High"

Low = 'Low'
Normal = 'Normal'
High = 'High'